package androidx.core.graphics;

import android.graphics.Path;
import android.util.Log;
import androidx.annotation.RestrictTo;
import java.util.ArrayList;
@RestrictTo({RestrictTo.Scope.LIBRARY_GROUP})
/* loaded from: classes.dex */
public class PathParser {
    private static final String LOGTAG = "PathParser";

    static float[] copyOfRange(float[] fArr, int i, int i2) {
        if (i > i2) {
            throw new IllegalArgumentException();
        }
        int length = fArr.length;
        if (i < 0 || i > length) {
            throw new ArrayIndexOutOfBoundsException();
        }
        int i3 = i2 - i;
        int min = Math.min(i3, length - i);
        float[] fArr2 = new float[i3];
        System.arraycopy(fArr, i, fArr2, 0, min);
        return fArr2;
    }

    public static Path createPathFromPathData(String str) {
        Path path = new Path();
        PathDataNode[] createNodesFromPathData = createNodesFromPathData(str);
        if (createNodesFromPathData != null) {
            try {
                PathDataNode.nodesToPath(createNodesFromPathData, path);
                return path;
            } catch (RuntimeException e) {
                throw new RuntimeException("Error in parsing " + str, e);
            }
        }
        return null;
    }

    public static PathDataNode[] createNodesFromPathData(String str) {
        if (str == null) {
            return null;
        }
        int i = 0;
        int i2 = 1;
        ArrayList arrayList = new ArrayList();
        while (i2 < str.length()) {
            int nextStart = nextStart(str, i2);
            String trim = str.substring(i, nextStart).trim();
            if (trim.length() > 0) {
                addNode(arrayList, trim.charAt(0), getFloats(trim));
            }
            i = nextStart;
            i2 = nextStart + 1;
        }
        if (i2 - i == 1 && i < str.length()) {
            addNode(arrayList, str.charAt(i), new float[0]);
        }
        return (PathDataNode[]) arrayList.toArray(new PathDataNode[arrayList.size()]);
    }

    public static PathDataNode[] deepCopyNodes(PathDataNode[] pathDataNodeArr) {
        if (pathDataNodeArr == null) {
            return null;
        }
        PathDataNode[] pathDataNodeArr2 = new PathDataNode[pathDataNodeArr.length];
        for (int i = 0; i < pathDataNodeArr.length; i++) {
            pathDataNodeArr2[i] = new PathDataNode(pathDataNodeArr[i]);
        }
        return pathDataNodeArr2;
    }

    public static boolean canMorph(PathDataNode[] pathDataNodeArr, PathDataNode[] pathDataNodeArr2) {
        if (pathDataNodeArr == null || pathDataNodeArr2 == null) {
            return false;
        }
        if (pathDataNodeArr.length != pathDataNodeArr2.length) {
            return false;
        }
        for (int i = 0; i < pathDataNodeArr.length; i++) {
            if (pathDataNodeArr[i].mType != pathDataNodeArr2[i].mType || pathDataNodeArr[i].mParams.length != pathDataNodeArr2[i].mParams.length) {
                return false;
            }
        }
        return true;
    }

    public static void updateNodes(PathDataNode[] pathDataNodeArr, PathDataNode[] pathDataNodeArr2) {
        for (int i = 0; i < pathDataNodeArr2.length; i++) {
            pathDataNodeArr[i].mType = pathDataNodeArr2[i].mType;
            for (int i2 = 0; i2 < pathDataNodeArr2[i].mParams.length; i2++) {
                pathDataNodeArr[i].mParams[i2] = pathDataNodeArr2[i].mParams[i2];
            }
        }
    }

    private static int nextStart(String str, int i) {
        int i2 = i;
        while (i2 < str.length()) {
            char charAt = str.charAt(i2);
            if (((charAt - 'A') * (charAt - 'Z') <= 0 || (charAt - 'a') * (charAt - 'z') <= 0) && charAt != 'e' && charAt != 'E') {
                return i2;
            }
            i2++;
        }
        return i2;
    }

    private static void addNode(ArrayList<PathDataNode> arrayList, char c, float[] fArr) {
        arrayList.add(new PathDataNode(c, fArr));
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes.dex */
    public static class ExtractFloatResult {
        int mEndPosition;
        boolean mEndWithNegOrDot;

        ExtractFloatResult() {
        }
    }

    private static float[] getFloats(String str) {
        if (str.charAt(0) == 'z' || str.charAt(0) == 'Z') {
            return new float[0];
        }
        try {
            float[] fArr = new float[str.length()];
            int i = 0;
            int i2 = 1;
            ExtractFloatResult extractFloatResult = new ExtractFloatResult();
            int length = str.length();
            while (i2 < length) {
                extract(str, i2, extractFloatResult);
                int i3 = extractFloatResult.mEndPosition;
                if (i2 < i3) {
                    int i4 = i;
                    i++;
                    fArr[i4] = Float.parseFloat(str.substring(i2, i3));
                }
                if (extractFloatResult.mEndWithNegOrDot) {
                    i2 = i3;
                } else {
                    i2 = i3 + 1;
                }
            }
            return copyOfRange(fArr, 0, i);
        } catch (NumberFormatException e) {
            throw new RuntimeException("error in parsing \"" + str + "\"", e);
        }
    }

    private static void extract(String str, int i, ExtractFloatResult extractFloatResult) {
        boolean z = false;
        extractFloatResult.mEndWithNegOrDot = false;
        boolean z2 = false;
        boolean z3 = false;
        for (int i2 = i; i2 < str.length(); i2++) {
            boolean z4 = z3;
            z3 = false;
            switch (str.charAt(i2)) {
                case ' ':
                case ',':
                    z = true;
                    break;
                case '-':
                    if (i2 != i && !z4) {
                        z = true;
                        extractFloatResult.mEndWithNegOrDot = true;
                        break;
                    }
                    break;
                case '.':
                    if (!z2) {
                        z2 = true;
                        break;
                    } else {
                        z = true;
                        extractFloatResult.mEndWithNegOrDot = true;
                        break;
                    }
                case 'E':
                case 'e':
                    z3 = true;
                    break;
            }
            if (z) {
                extractFloatResult.mEndPosition = i2;
            }
        }
        extractFloatResult.mEndPosition = i2;
    }

    /* loaded from: classes.dex */
    public static class PathDataNode {
        @RestrictTo({RestrictTo.Scope.LIBRARY_GROUP})
        public float[] mParams;
        @RestrictTo({RestrictTo.Scope.LIBRARY_GROUP})
        public char mType;

        PathDataNode(char c, float[] fArr) {
            this.mType = c;
            this.mParams = fArr;
        }

        PathDataNode(PathDataNode pathDataNode) {
            this.mType = pathDataNode.mType;
            this.mParams = PathParser.copyOfRange(pathDataNode.mParams, 0, pathDataNode.mParams.length);
        }

        public static void nodesToPath(PathDataNode[] pathDataNodeArr, Path path) {
            float[] fArr = new float[6];
            char c = 'm';
            for (int i = 0; i < pathDataNodeArr.length; i++) {
                addCommand(path, fArr, c, pathDataNodeArr[i].mType, pathDataNodeArr[i].mParams);
                c = pathDataNodeArr[i].mType;
            }
        }

        public void interpolatePathDataNode(PathDataNode pathDataNode, PathDataNode pathDataNode2, float f) {
            for (int i = 0; i < pathDataNode.mParams.length; i++) {
                this.mParams[i] = (pathDataNode.mParams[i] * (1.0f - f)) + (pathDataNode2.mParams[i] * f);
            }
        }

        private static void addCommand(Path path, float[] fArr, char c, char c2, float[] fArr2) {
            char c3 = c;
            int i = 2;
            float f = fArr[0];
            float f2 = fArr[1];
            float f3 = fArr[2];
            float f4 = fArr[3];
            float f5 = fArr[4];
            float f6 = fArr[5];
            switch (c2) {
                case 'A':
                case 'a':
                    i = 7;
                    break;
                case 'C':
                case 'c':
                    i = 6;
                    break;
                case 'H':
                case 'V':
                case 'h':
                case 'v':
                    i = 1;
                    break;
                case 'L':
                case 'M':
                case 'T':
                case 'l':
                case 'm':
                case 't':
                    i = 2;
                    break;
                case 'Q':
                case 'S':
                case 'q':
                case 's':
                    i = 4;
                    break;
                case 'Z':
                case 'z':
                    path.close();
                    f = f5;
                    f2 = f6;
                    f3 = f5;
                    f4 = f6;
                    path.moveTo(f, f2);
                    break;
            }
            int i2 = 0;
            while (true) {
                int i3 = i2;
                if (i3 < fArr2.length) {
                    switch (c2) {
                        case 'A':
                            drawArc(path, f, f2, fArr2[i3 + 5], fArr2[i3 + 6], fArr2[i3 + 0], fArr2[i3 + 1], fArr2[i3 + 2], fArr2[i3 + 3] != 0.0f, fArr2[i3 + 4] != 0.0f);
                            f = fArr2[i3 + 5];
                            f2 = fArr2[i3 + 6];
                            f3 = f;
                            f4 = f2;
                            break;
                        case 'C':
                            path.cubicTo(fArr2[i3 + 0], fArr2[i3 + 1], fArr2[i3 + 2], fArr2[i3 + 3], fArr2[i3 + 4], fArr2[i3 + 5]);
                            f = fArr2[i3 + 4];
                            f2 = fArr2[i3 + 5];
                            f3 = fArr2[i3 + 2];
                            f4 = fArr2[i3 + 3];
                            break;
                        case 'H':
                            path.lineTo(fArr2[i3 + 0], f2);
                            f = fArr2[i3 + 0];
                            break;
                        case 'L':
                            path.lineTo(fArr2[i3 + 0], fArr2[i3 + 1]);
                            f = fArr2[i3 + 0];
                            f2 = fArr2[i3 + 1];
                            break;
                        case 'M':
                            f = fArr2[i3 + 0];
                            f2 = fArr2[i3 + 1];
                            if (i3 > 0) {
                                path.lineTo(fArr2[i3 + 0], fArr2[i3 + 1]);
                                break;
                            } else {
                                path.moveTo(fArr2[i3 + 0], fArr2[i3 + 1]);
                                f5 = f;
                                f6 = f2;
                                break;
                            }
                        case 'Q':
                            path.quadTo(fArr2[i3 + 0], fArr2[i3 + 1], fArr2[i3 + 2], fArr2[i3 + 3]);
                            f3 = fArr2[i3 + 0];
                            f4 = fArr2[i3 + 1];
                            f = fArr2[i3 + 2];
                            f2 = fArr2[i3 + 3];
                            break;
                        case 'S':
                            float f7 = f;
                            float f8 = f2;
                            if (c3 == 'c' || c3 == 's' || c3 == 'C' || c3 == 'S') {
                                f7 = (2.0f * f) - f3;
                                f8 = (2.0f * f2) - f4;
                            }
                            path.cubicTo(f7, f8, fArr2[i3 + 0], fArr2[i3 + 1], fArr2[i3 + 2], fArr2[i3 + 3]);
                            f3 = fArr2[i3 + 0];
                            f4 = fArr2[i3 + 1];
                            f = fArr2[i3 + 2];
                            f2 = fArr2[i3 + 3];
                            break;
                        case 'T':
                            float f9 = f;
                            float f10 = f2;
                            if (c3 == 'q' || c3 == 't' || c3 == 'Q' || c3 == 'T') {
                                f9 = (2.0f * f) - f3;
                                f10 = (2.0f * f2) - f4;
                            }
                            path.quadTo(f9, f10, fArr2[i3 + 0], fArr2[i3 + 1]);
                            f3 = f9;
                            f4 = f10;
                            f = fArr2[i3 + 0];
                            f2 = fArr2[i3 + 1];
                            break;
                        case 'V':
                            path.lineTo(f, fArr2[i3 + 0]);
                            f2 = fArr2[i3 + 0];
                            break;
                        case 'a':
                            drawArc(path, f, f2, fArr2[i3 + 5] + f, fArr2[i3 + 6] + f2, fArr2[i3 + 0], fArr2[i3 + 1], fArr2[i3 + 2], fArr2[i3 + 3] != 0.0f, fArr2[i3 + 4] != 0.0f);
                            f += fArr2[i3 + 5];
                            f2 += fArr2[i3 + 6];
                            f3 = f;
                            f4 = f2;
                            break;
                        case 'c':
                            path.rCubicTo(fArr2[i3 + 0], fArr2[i3 + 1], fArr2[i3 + 2], fArr2[i3 + 3], fArr2[i3 + 4], fArr2[i3 + 5]);
                            f3 = f + fArr2[i3 + 2];
                            f4 = f2 + fArr2[i3 + 3];
                            f += fArr2[i3 + 4];
                            f2 += fArr2[i3 + 5];
                            break;
                        case 'h':
                            path.rLineTo(fArr2[i3 + 0], 0.0f);
                            f += fArr2[i3 + 0];
                            break;
                        case 'l':
                            path.rLineTo(fArr2[i3 + 0], fArr2[i3 + 1]);
                            f += fArr2[i3 + 0];
                            f2 += fArr2[i3 + 1];
                            break;
                        case 'm':
                            f += fArr2[i3 + 0];
                            f2 += fArr2[i3 + 1];
                            if (i3 > 0) {
                                path.rLineTo(fArr2[i3 + 0], fArr2[i3 + 1]);
                                break;
                            } else {
                                path.rMoveTo(fArr2[i3 + 0], fArr2[i3 + 1]);
                                f5 = f;
                                f6 = f2;
                                break;
                            }
                        case 'q':
                            path.rQuadTo(fArr2[i3 + 0], fArr2[i3 + 1], fArr2[i3 + 2], fArr2[i3 + 3]);
                            f3 = f + fArr2[i3 + 0];
                            f4 = f2 + fArr2[i3 + 1];
                            f += fArr2[i3 + 2];
                            f2 += fArr2[i3 + 3];
                            break;
                        case 's':
                            float f11 = 0.0f;
                            float f12 = 0.0f;
                            if (c3 == 'c' || c3 == 's' || c3 == 'C' || c3 == 'S') {
                                f11 = f - f3;
                                f12 = f2 - f4;
                            }
                            path.rCubicTo(f11, f12, fArr2[i3 + 0], fArr2[i3 + 1], fArr2[i3 + 2], fArr2[i3 + 3]);
                            f3 = f + fArr2[i3 + 0];
                            f4 = f2 + fArr2[i3 + 1];
                            f += fArr2[i3 + 2];
                            f2 += fArr2[i3 + 3];
                            break;
                        case 't':
                            float f13 = 0.0f;
                            float f14 = 0.0f;
                            if (c3 == 'q' || c3 == 't' || c3 == 'Q' || c3 == 'T') {
                                f13 = f - f3;
                                f14 = f2 - f4;
                            }
                            path.rQuadTo(f13, f14, fArr2[i3 + 0], fArr2[i3 + 1]);
                            f3 = f + f13;
                            f4 = f2 + f14;
                            f += fArr2[i3 + 0];
                            f2 += fArr2[i3 + 1];
                            break;
                        case 'v':
                            path.rLineTo(0.0f, fArr2[i3 + 0]);
                            f2 += fArr2[i3 + 0];
                            break;
                    }
                    c3 = c2;
                    i2 = i3 + i;
                } else {
                    fArr[0] = f;
                    fArr[1] = f2;
                    fArr[2] = f3;
                    fArr[3] = f4;
                    fArr[4] = f5;
                    fArr[5] = f6;
                    return;
                }
            }
        }

        private static void drawArc(Path path, float f, float f2, float f3, float f4, float f5, float f6, float f7, boolean z, boolean z2) {
            double d;
            double d2;
            double radians = Math.toRadians(f7);
            double cos = Math.cos(radians);
            double sin = Math.sin(radians);
            double d3 = ((f * cos) + (f2 * sin)) / f5;
            double d4 = (((-f) * sin) + (f2 * cos)) / f6;
            double d5 = ((f3 * cos) + (f4 * sin)) / f5;
            double d6 = (((-f3) * sin) + (f4 * cos)) / f6;
            double d7 = d3 - d5;
            double d8 = d4 - d6;
            double d9 = (d3 + d5) / 2.0d;
            double d10 = (d4 + d6) / 2.0d;
            double d11 = (d7 * d7) + (d8 * d8);
            if (d11 == 0.0d) {
                Log.w(PathParser.LOGTAG, " Points are coincident");
                return;
            }
            double d12 = (1.0d / d11) - 0.25d;
            if (d12 < 0.0d) {
                Log.w(PathParser.LOGTAG, "Points are too far apart " + d11);
                float sqrt = (float) (Math.sqrt(d11) / 1.99999d);
                drawArc(path, f, f2, f3, f4, f5 * sqrt, f6 * sqrt, f7, z, z2);
                return;
            }
            double sqrt2 = Math.sqrt(d12);
            double d13 = sqrt2 * d7;
            double d14 = sqrt2 * d8;
            if (z == z2) {
                d = d9 - d14;
                d2 = d10 + d13;
            } else {
                d = d9 + d14;
                d2 = d10 - d13;
            }
            double atan2 = Math.atan2(d4 - d2, d3 - d);
            double atan22 = Math.atan2(d6 - d2, d5 - d) - atan2;
            if (z2 != (atan22 >= 0.0d)) {
                if (atan22 > 0.0d) {
                    atan22 -= 6.283185307179586d;
                } else {
                    atan22 += 6.283185307179586d;
                }
            }
            double d15 = d * f5;
            double d16 = d2 * f6;
            arcToBezier(path, (d15 * cos) - (d16 * sin), (d15 * sin) + (d16 * cos), f5, f6, f, f2, radians, atan2, atan22);
        }

        private static void arcToBezier(Path path, double d, double d2, double d3, double d4, double d5, double d6, double d7, double d8, double d9) {
            double d10 = d5;
            double d11 = d6;
            int ceil = (int) Math.ceil(Math.abs((d9 * 4.0d) / 3.141592653589793d));
            double d12 = d8;
            double cos = Math.cos(d7);
            double sin = Math.sin(d7);
            double cos2 = Math.cos(d12);
            double sin2 = Math.sin(d12);
            double d13 = (((-d3) * cos) * sin2) - ((d4 * sin) * cos2);
            double d14 = ((-d3) * sin * sin2) + (d4 * cos * cos2);
            double d15 = d9 / ceil;
            for (int i = 0; i < ceil; i++) {
                double d16 = d12 + d15;
                double sin3 = Math.sin(d16);
                double cos3 = Math.cos(d16);
                double d17 = (d + ((d3 * cos) * cos3)) - ((d4 * sin) * sin3);
                double d18 = d2 + (d3 * sin * cos3) + (d4 * cos * sin3);
                double d19 = (((-d3) * cos) * sin3) - ((d4 * sin) * cos3);
                double d20 = ((-d3) * sin * sin3) + (d4 * cos * cos3);
                double tan = Math.tan((d16 - d12) / 2.0d);
                double sin4 = (Math.sin(d16 - d12) * (Math.sqrt(4.0d + ((3.0d * tan) * tan)) - 1.0d)) / 3.0d;
                path.rLineTo(0.0f, 0.0f);
                path.cubicTo((float) (d10 + (sin4 * d13)), (float) (d11 + (sin4 * d14)), (float) (d17 - (sin4 * d19)), (float) (d18 - (sin4 * d20)), (float) d17, (float) d18);
                d12 = d16;
                d10 = d17;
                d11 = d18;
                d13 = d19;
                d14 = d20;
            }
        }
    }

    private PathParser() {
    }
}
