package androidx.transition;

import android.graphics.Rect;
import android.view.View;
import android.view.ViewGroup;
import androidx.core.view.GravityCompat;
import androidx.core.view.ViewCompat;
/* loaded from: classes.dex */
public class SidePropagation extends VisibilityPropagation {
    private float mPropagationSpeed = 3.0f;
    private int mSide = 80;

    public void setSide(int i) {
        this.mSide = i;
    }

    public void setPropagationSpeed(float f) {
        if (f == 0.0f) {
            throw new IllegalArgumentException("propagationSpeed may not be 0");
        }
        this.mPropagationSpeed = f;
    }

    @Override // androidx.transition.TransitionPropagation
    public long getStartDelay(ViewGroup viewGroup, Transition transition, TransitionValues transitionValues, TransitionValues transitionValues2) {
        TransitionValues transitionValues3;
        int i;
        int i2;
        if (transitionValues == null && transitionValues2 == null) {
            return 0L;
        }
        int i3 = 1;
        Rect epicenter = transition.getEpicenter();
        if (transitionValues2 == null || getViewVisibility(transitionValues) == 0) {
            transitionValues3 = transitionValues;
            i3 = -1;
        } else {
            transitionValues3 = transitionValues2;
        }
        int viewX = getViewX(transitionValues3);
        int viewY = getViewY(transitionValues3);
        int[] iArr = new int[2];
        viewGroup.getLocationOnScreen(iArr);
        int round = iArr[0] + Math.round(viewGroup.getTranslationX());
        int round2 = iArr[1] + Math.round(viewGroup.getTranslationY());
        int width = round + viewGroup.getWidth();
        int height = round2 + viewGroup.getHeight();
        if (epicenter != null) {
            i = epicenter.centerX();
            i2 = epicenter.centerY();
        } else {
            i = (round + width) / 2;
            i2 = (round2 + height) / 2;
        }
        float distance = distance(viewGroup, viewX, viewY, i, i2, round, round2, width, height) / getMaxDistance(viewGroup);
        long duration = transition.getDuration();
        if (duration < 0) {
            duration = 300;
        }
        return Math.round((((float) (duration * i3)) / this.mPropagationSpeed) * distance);
    }

    private int distance(View view, int i, int i2, int i3, int i4, int i5, int i6, int i7, int i8) {
        int i9;
        if (this.mSide == 8388611) {
            i9 = ViewCompat.getLayoutDirection(view) == 1 ? 5 : 3;
        } else if (this.mSide == 8388613) {
            i9 = ViewCompat.getLayoutDirection(view) == 1 ? 3 : 5;
        } else {
            i9 = this.mSide;
        }
        int i10 = 0;
        switch (i9) {
            case 3:
                i10 = (i7 - i) + Math.abs(i4 - i2);
                break;
            case 5:
                i10 = (i - i5) + Math.abs(i4 - i2);
                break;
            case 48:
                i10 = (i8 - i2) + Math.abs(i3 - i);
                break;
            case 80:
                i10 = (i2 - i6) + Math.abs(i3 - i);
                break;
        }
        return i10;
    }

    private int getMaxDistance(ViewGroup viewGroup) {
        switch (this.mSide) {
            case 3:
            case 5:
            case GravityCompat.START /* 8388611 */:
            case GravityCompat.END /* 8388613 */:
                return viewGroup.getWidth();
            default:
                return viewGroup.getHeight();
        }
    }
}
