package com.google.android.material.ripple;

import android.annotation.TargetApi;
import android.content.res.ColorStateList;
import android.graphics.Color;
import android.os.Build;
import android.util.StateSet;
import androidx.annotation.ColorInt;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.annotation.RestrictTo;
import androidx.core.graphics.ColorUtils;
@RestrictTo({RestrictTo.Scope.LIBRARY_GROUP})
/* loaded from: classes.dex */
public class RippleUtils {
    private static final int[] FOCUSED_STATE_SET;
    private static final int[] HOVERED_FOCUSED_STATE_SET;
    private static final int[] HOVERED_STATE_SET;
    private static final int[] PRESSED_STATE_SET;
    private static final int[] SELECTED_FOCUSED_STATE_SET;
    private static final int[] SELECTED_HOVERED_FOCUSED_STATE_SET;
    private static final int[] SELECTED_HOVERED_STATE_SET;
    private static final int[] SELECTED_PRESSED_STATE_SET;
    private static final int[] SELECTED_STATE_SET;
    public static final boolean USE_FRAMEWORK_RIPPLE;

    static {
        USE_FRAMEWORK_RIPPLE = Build.VERSION.SDK_INT >= 21;
        PRESSED_STATE_SET = new int[]{16842919};
        HOVERED_FOCUSED_STATE_SET = new int[]{16843623, 16842908};
        FOCUSED_STATE_SET = new int[]{16842908};
        HOVERED_STATE_SET = new int[]{16843623};
        SELECTED_PRESSED_STATE_SET = new int[]{16842913, 16842919};
        SELECTED_HOVERED_FOCUSED_STATE_SET = new int[]{16842913, 16843623, 16842908};
        SELECTED_FOCUSED_STATE_SET = new int[]{16842913, 16842908};
        SELECTED_HOVERED_STATE_SET = new int[]{16842913, 16843623};
        SELECTED_STATE_SET = new int[]{16842913};
    }

    private RippleUtils() {
    }

    @NonNull
    public static ColorStateList convertToRippleDrawableColor(@Nullable ColorStateList colorStateList) {
        if (USE_FRAMEWORK_RIPPLE) {
            int[][] iArr = new int[2];
            int[] iArr2 = new int[2];
            iArr[0] = SELECTED_STATE_SET;
            iArr2[0] = getColorForState(colorStateList, SELECTED_PRESSED_STATE_SET);
            int i = 0 + 1;
            iArr[i] = StateSet.NOTHING;
            iArr2[i] = getColorForState(colorStateList, PRESSED_STATE_SET);
            int i2 = i + 1;
            return new ColorStateList(iArr, iArr2);
        }
        int[][] iArr3 = new int[10];
        int[] iArr4 = new int[10];
        iArr3[0] = SELECTED_PRESSED_STATE_SET;
        iArr4[0] = getColorForState(colorStateList, SELECTED_PRESSED_STATE_SET);
        int i3 = 0 + 1;
        iArr3[i3] = SELECTED_HOVERED_FOCUSED_STATE_SET;
        iArr4[i3] = getColorForState(colorStateList, SELECTED_HOVERED_FOCUSED_STATE_SET);
        int i4 = i3 + 1;
        iArr3[i4] = SELECTED_FOCUSED_STATE_SET;
        iArr4[i4] = getColorForState(colorStateList, SELECTED_FOCUSED_STATE_SET);
        int i5 = i4 + 1;
        iArr3[i5] = SELECTED_HOVERED_STATE_SET;
        iArr4[i5] = getColorForState(colorStateList, SELECTED_HOVERED_STATE_SET);
        int i6 = i5 + 1;
        iArr3[i6] = SELECTED_STATE_SET;
        iArr4[i6] = 0;
        int i7 = i6 + 1;
        iArr3[i7] = PRESSED_STATE_SET;
        iArr4[i7] = getColorForState(colorStateList, PRESSED_STATE_SET);
        int i8 = i7 + 1;
        iArr3[i8] = HOVERED_FOCUSED_STATE_SET;
        iArr4[i8] = getColorForState(colorStateList, HOVERED_FOCUSED_STATE_SET);
        int i9 = i8 + 1;
        iArr3[i9] = FOCUSED_STATE_SET;
        iArr4[i9] = getColorForState(colorStateList, FOCUSED_STATE_SET);
        int i10 = i9 + 1;
        iArr3[i10] = HOVERED_STATE_SET;
        iArr4[i10] = getColorForState(colorStateList, HOVERED_STATE_SET);
        int i11 = i10 + 1;
        iArr3[i11] = StateSet.NOTHING;
        iArr4[i11] = 0;
        int i12 = i11 + 1;
        return new ColorStateList(iArr3, iArr4);
    }

    @ColorInt
    private static int getColorForState(@Nullable ColorStateList colorStateList, int[] iArr) {
        int i;
        if (colorStateList != null) {
            i = colorStateList.getColorForState(iArr, colorStateList.getDefaultColor());
        } else {
            i = 0;
        }
        return USE_FRAMEWORK_RIPPLE ? doubleAlpha(i) : i;
    }

    @ColorInt
    @TargetApi(21)
    private static int doubleAlpha(@ColorInt int i) {
        return ColorUtils.setAlphaComponent(i, Math.min(2 * Color.alpha(i), 255));
    }
}
